@@ -1,12 +1,11 @@
 #![allow(clippy::redundant_allocation)]
 
-use self::static_check::should_use_create_element;
-use crate::refresh::options::{deserialize_refresh, RefreshOptions};
+use std::{borrow::Cow, iter, iter::once, mem, sync::Arc};
+
 use dashmap::DashMap;
 use once_cell::sync::Lazy;
 use regex::Regex;
 use serde::{Deserialize, Serialize};
-use std::{borrow::Cow, iter, iter::once, mem, sync::Arc};
 use string_enum::StringEnum;
 use swc_atoms::{js_word, JsWord};
 use swc_common::{
@@ -25,6 +24,9 @@ use swc_ecma_utils::{
 };
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut, VisitMutWith};
 
+use self::static_check::should_use_create_element;
+use crate::refresh::options::{deserialize_refresh, RefreshOptions};
+
 mod static_check;
 #[cfg(test)]
 mod tests;
@@ -502,8 +504,7 @@ where
                                     if !use_create_element && i.sym == js_word!("key") {
                                         key = attr
                                             .value
-                                            .map(jsx_attr_value_to_expr)
-                                            .flatten()
+                                            .and_then(jsx_attr_value_to_expr)
                                             .map(|expr| ExprOrSpread { expr, spread: None });
                                         assert_ne!(
                                             key, None,
@@ -521,8 +522,7 @@ where
                                         }
                                         source_props = attr
                                             .value
-                                            .map(jsx_attr_value_to_expr)
-                                            .flatten()
+                                            .and_then(jsx_attr_value_to_expr)
                                             .map(|expr| ExprOrSpread { expr, spread: None });
                                         assert_ne!(
                                             source_props, None,
@@ -540,8 +540,7 @@ where
                                         }
                                         self_props = attr
                                             .value
-                                            .map(jsx_attr_value_to_expr)
-                                            .flatten()
+                                            .and_then(jsx_attr_value_to_expr)
                                             .map(|expr| ExprOrSpread { expr, spread: None });
                                         assert_ne!(
                                             self_props, None,
@@ -1027,19 +1026,6 @@ where
         self.top_level_node = top_level_node;
     }
 
-    fn visit_mut_member_expr(&mut self, e: &mut MemberExpr) {
-        e.obj.visit_mut_with(self);
-        if let MemberProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
-    fn visit_mut_super_prop_expr(&mut self, e: &mut SuperPropExpr) {
-        if let SuperProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
     fn visit_mut_module(&mut self, module: &mut Module) {
         self.parse_directives(module.span);
 
